OperatingProfile

Struct OperatingProfile 

pub struct OperatingProfile {
Show 14 fields pub financial_fields: [&'static str; 16], pub financial_count: u8, pub authority_surfaces: [&'static str; 16], pub authority_count: u8, pub append_only_segments: [&'static str; 8], pub append_only_count: u8, pub migration_sensitive: [&'static str; 8], pub migration_sensitive_count: u8, pub stability_grades: [(&'static str, LayoutStabilityGrade); 8], pub stability_count: u8, pub has_financial_ops: bool, pub has_cpi_ops: bool, pub has_migration_paths: bool, pub has_receipts: bool,
}
A machine-readable summary of a program’s operational characteristics.

Generated from a ProgramManifest to give auditors, dashboards, explorers, and operator tools a meaningful map of how the program behaves.

Fields

financial_fields: [&'static str; 16]

Fields classified as financial (balance, supply, basis_points).

financial_count: u8

Number of valid financial field entries.

authority_surfaces: [&'static str; 16]

Fields classified as authority surfaces (authority, owner, delegate).

authority_count: u8

Number of valid authority surface entries.

append_only_segments: [&'static str; 8]

Segments that are append-only.

append_only_count: u8

Number of valid append-only segment entries.

migration_sensitive: [&'static str; 8]

Segments sensitive to migration.

migration_sensitive_count: u8

Number of valid migration-sensitive entries.

stability_grades: [(&'static str, LayoutStabilityGrade); 8]

Layout stability grades per layout.

stability_count: u8

Number of valid stability grade entries.

has_financial_ops: bool

Whether the program has any financial operations.

has_cpi_ops: bool

Whether the program has any CPI-invoking instructions.

has_migration_paths: bool

Whether the program has migration paths defined.

has_receipts: bool

Whether the program emits receipts.

Implementations

Source

impl OperatingProfile

pub fn from_manifest(manifest: &ProgramManifest) -> Self

Generate an operating profile from a program manifest.