pub trait AccountSchemaExt {
// Required methods
fn manager_metadata_for<T: SchemaExport>(&self) -> Option<ManagerMetadata>;
fn schema_bundle_for<T: SchemaExport>(&self) -> Option<SchemaBundle>;
}Expand description
Bridge from a live AccountView to the schema bundle of a concrete layout type.
Required Methods
Sourcefn manager_metadata_for<T: SchemaExport>(&self) -> Option<ManagerMetadata>
fn manager_metadata_for<T: SchemaExport>(&self) -> Option<ManagerMetadata>
Return manager metadata if the account header matches T.
Sourcefn schema_bundle_for<T: SchemaExport>(&self) -> Option<SchemaBundle>
fn schema_bundle_for<T: SchemaExport>(&self) -> Option<SchemaBundle>
Return the full schema bundle if the account header matches T.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.